@@ -9,9 +9,8 @@ from langchain_core.runnables import (
     RunnableConfig,
 )
 from pydantic import BaseModel, Field
+from mtmai.agents.tools.wikipedia import MtmTopicDocRetriever
 import mtmai.chainlit as cl
-from mtmai.agents.retrivers.wikipedia import MtmTopicDocRetriever
-# from mtmai.agents.ctx import get_mtmai_ctx
 from mtmai.agents.ctx import mtmai_context
 
 from mtmai.core.logging import get_logger
