@@ -13,7 +13,7 @@ async def is_thread_author(username: str, thread_id: str):
     if not thread_author:
         raise HTTPException(status_code=404, detail="Thread not found")
 
-    if thread_author != username:
+    if thread_author != str(username):
         raise HTTPException(status_code=401, detail="Unauthorized")
     else:
         return True
