@@ -792,23 +792,23 @@ async def get_thread(
     return JSONResponse(content=res)
 
 
-@router.get("/project/thread/{thread_id}/element/{element_id}")
-async def get_thread_element(
-    request: Request,
-    thread_id: str,
-    element_id: str,
-    current_user: Annotated[Union[User, PersistedUser], Depends(get_current_user)],
-):
-    """Get a specific thread element."""
-    data_layer = get_data_layer()
+# @router.get("/project/thread/{thread_id}/element/{element_id}")
+# async def get_thread_element(
+#     request: Request,
+#     thread_id: str,
+#     element_id: str,
+#     current_user: Annotated[Union[User, PersistedUser], Depends(get_current_user)],
+# ):
+#     """Get a specific thread element."""
+#     data_layer = get_data_layer()
 
-    if not data_layer:
-        raise HTTPException(status_code=400, detail="Data persistence is not enabled")
+#     if not data_layer:
+#         raise HTTPException(status_code=400, detail="Data persistence is not enabled")
 
-    await is_thread_author(current_user.identifier, thread_id)
+#     await is_thread_author(current_user.identifier, thread_id)
 
-    res = await data_layer.get_element(thread_id, element_id)
-    return JSONResponse(content=res)
+#     res = await data_layer.get_element(thread_id, element_id)
+#     return JSONResponse(content=res)
 
 
 @router.delete("/project/thread")
