@@ -11,6 +11,8 @@ def is_in_dev() -> bool:
     """是否处于开发环境"""
     from mtmai.core.config import settings
 
+    if is_in_gitpod():
+        return True
     return (
         not is_in_docker()
         and not is_in_vercel()
