@@ -6,7 +6,7 @@ import asyncio
 from datetime import timedelta
 from textwrap import dedent
 
-from prefect import flow, get_run_logger, task
+from prefect import get_run_logger, task
 from prefect.tasks import task_input_hash
 from pydantic import BaseModel
 
@@ -17,15 +17,20 @@ from mtmai.models.book_gen import (
     BookOutline,
     Chapter,
     ChapterOutline,
-    GenBookState,
     WriteOutlineRequest,
 )
+from mtmai.mtlibs.aiutils import get_json_format_instructions
 
 
-@task(cache_key_fn=task_input_hash, cache_expiration=timedelta(days=1))
+@task(
+    cache_key_fn=task_input_hash,
+    cache_expiration=timedelta(seconds=60),
+    retries=3,
+)
 async def article_gen_outline(*, req: WriteOutlineRequest) -> BookOutline:
     """生成文章大纲"""
     llm = await mtmai_context.get_crawai_llm()
+    logger = get_run_logger()
 
     researcher_agent = Agent(
         role="Research Agent",
@@ -64,7 +69,7 @@ It's important to note that each chapter is only going to be 3,000 words or less
 Also, make sure that you do not duplicate any chapters or topics in the outline.
 
 Here is some additional information about the author's desired goal for the book:\n\n {goal}"""),
-        expected_output="An outline of chapters, with titles and descriptions of what each chapter will contain. Maximum of 3 chapters.",
+        expected_output="An outline of chapters, with titles and descriptions of what each chapter will contain. Maximum of 3 chapters.  \n\n {format_instructions}",
         output_pydantic=BookOutline,
         agent=outliner_agent,
     )
@@ -74,7 +79,20 @@ Here is some additional information about the author's desired goal for the book
         process=Process.sequential,
         verbose=True,
     )
-    output = await crew.kickoff_async(inputs=req.model_dump())
+
+    inputs = req
+    if isinstance(req, BaseModel):
+        inputs = req.model_dump()
+    inputs["format_instructions"] = get_json_format_instructions(BookOutline)
+    output = await crew.kickoff_async(inputs=inputs)
+
+    logger.info(f"format_instructions: {get_json_format_instructions(BookOutline)}")
+    if not output:
+        raise ValueError(f"大纲生成失败: {req}")
+    if not output.pydantic:
+        raise ValueError(
+            f"大纲生成失败: 原因是 output.pydantic 没有正确的输出格式,原始内容: {output.raw}"
+        )
     return output.pydantic
 
 
@@ -88,9 +106,15 @@ class WriteSingleChapterRequest(BaseModel):
     book_outlines: list[ChapterOutline]
 
 
-@task(cache_key_fn=task_input_hash, cache_expiration=timedelta(days=1))
+@task(
+    cache_key_fn=task_input_hash,
+    cache_expiration=timedelta(days=1),
+    retries=3,
+)
 async def write_book_chapter_crew(*, req: WriteSingleChapterRequest):
     """生成文章一个章节"""
+    logger = get_run_logger()
+
     llm = await mtmai_context.get_crawai_llm()
 
     researcher_agent = Agent(
@@ -145,7 +169,7 @@ Important notes:
 Here is the outline of the entire book:\n\n
 {book_outlines}"""),
         agent=writer_agent,
-        expected_output="A markdown-formatted chapter of around 3,000 words that covers the provided chapter title and outline description.",
+        expected_output="A markdown-formatted chapter of around 3,000 words that covers the provided chapter title and outline description. \n\n {format_instructions}",
         output_pydantic=Chapter,
     )
     crew = Crew(
@@ -154,7 +178,15 @@ Here is the outline of the entire book:\n\n
         process=Process.sequential,
         verbose=True,
     )
-    output = await crew.kickoff_async(inputs=req.model_dump())
+    inputs = req.model_dump()
+    inputs["format_instructions"] = get_json_format_instructions(Chapter)
+    output = await crew.kickoff_async(inputs=inputs)
+    if not output:
+        raise ValueError(f"章节生成失败: {req}")
+    if not output.pydantic:
+        raise ValueError(
+            f"章节生成失败,原因是 output.pydantic 没有正确的输出格式,原始内容: \n========\n{output.raw}\n========\n"
+        )
     return output.pydantic
 
 
@@ -168,65 +200,7 @@ async def write_section(topic):
     return f"Content for {topic}"
 
 
-@flow
-async def flow_article_gen():
-    logger = get_run_logger()
-    logger.info("开始编写大纲")
-
-    # 创建大纲的逻辑
-    logger = get_run_logger()
-    logger.info("flow_article_gen start ...")
-    state = GenBookState()
-    outlines = await article_gen_outline(
-        req=WriteOutlineRequest(
-            topic=state.topic,
-            goal=state.goal,
-        )
-    )
-
-    logger.info("大纲编写完成，开始写内容")
-
-    chapters = outlines.chapters
-    state.book_outline = chapters
-
-    chapters = []
-    for index, chapter_outline in enumerate(state.book_outline, start=1):
-        logger.info(
-            f"开始写章节正文 {index}/{len(state.book_outline)}: {chapter_outline.title}"
-        )
-        output = await write_book_chapter_crew(
-            req=WriteSingleChapterRequest(
-                goal=state.goal,
-                topic=state.topic,
-                chapter_title=chapter_outline.title,
-                chapter_description=chapter_outline.description,
-                book_outlines=state.book_outline,
-            )
-        )
-        chapters.append(Chapter(title=output.title, content=output.content))
-
-    state.book.extend(chapters)
-    # sections = [await write_section(topic) for topic in outline]
-    logger.info(f"章节内容写入完成, 章节数量:{len(chapters)}")
-
-    logger.info(f"文章数据转换为markdown 格式:{len(chapters)}")
-
-    book_content = ""
-    for chapter in state.book:
-        # Add the chapter title as an H1 heading
-        book_content += f"# {chapter.title}\n\n"
-        # Add the chapter content
-        book_content += f"{chapter.content}\n\n"
-
-    # The title of the book from self.state.title
-    book_title = state.title
-
-    logger.info("文章生成完成, 开始导出")
-    filename = f"./{book_title.replace(' ', '_')}.md"
-
-    # Save the combined content into the file
-    with open(filename, "w", encoding="utf-8") as file:
-        file.write(book_content)
-
-    logger.info("Book saved as %s", filename)
-    return book_content
+class ArticleGenStateRequest(BaseModel):
+    topic: str | None = None
+    user_id: str | None = None
+    site_id: str | None = None
