@@ -1,11 +1,12 @@
 """
 工作流： 练习和测试
 """
+
 import asyncio
 from datetime import timedelta
-from prefect import flow, task, get_run_logger,serve
-from prefect.tasks import task_input_hash
 
+from prefect import flow, get_run_logger, task
+from prefect.tasks import task_input_hash
 
 
 @task(cache_key_fn=task_input_hash, cache_expiration=timedelta(days=1))
@@ -18,6 +19,7 @@ async def create_outline():
         outline.append(f"Topic {i+1}")
     return outline
 
+
 @task(cache_key_fn=task_input_hash, cache_expiration=timedelta(days=1))
 async def write_section(topic):
     logger = get_run_logger()
@@ -27,6 +29,7 @@ async def write_section(topic):
 
     return f"Content for {topic}"
 
+
 @flow
 async def flow_hello(goodbye=False):
     logger = get_run_logger()
