@@ -7,15 +7,16 @@ from sqlmodel import JSON, Column, Field
 
 from mtmai.models.agent import CopilotScreen
 from mtmai.models.base_model import MtmBaseSqlModel
+from mtmai.models.search_index import SearchRequest
 
 
 class ChatThread(MtmBaseSqlModel, table=True):
     id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
     name: str = Field(nullable=True)
-    user_id: uuid.UUID | None = Field(
+    userId: uuid.UUID | None = Field(
         foreign_key="user.id", index=True, nullable=False, ondelete="CASCADE"
     )
-    user_identifier: str = Field(nullable=True)
+    userIdentifier: str = Field(nullable=True)
     tags: list[str] = Field(default=[], sa_column=Column(JSON))
     meta: dict | None = Field(default={}, sa_column=Column(JSON))
 
@@ -46,23 +47,24 @@ class ChatStep(MtmBaseSqlModel, table=True):
     _upsert_index_elements = {"id"}
 
 
-
 class ChatElement(MtmBaseSqlModel, table=True):
     id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
-    thread_id: uuid.UUID | None = Field(default=None)
+    threadId: uuid.UUID | None = Field(default=None, index=True)
     type: str | None = Field(default=None)
     url: str | None = Field(default=None)
-    chainlit_key: str | None = Field(default=None)
+    chainlitKey: str | None = Field(default=None)
     name: str = Field(...)
     display: str | None = Field(default=None)
-    object_key: str | None = Field(default=None)
+    objectKey: str | None = Field(default=None)
     size: str | None = Field(default=None)
     page: int | None = Field(default=None)
     language: str | None = Field(default=None)
-    for_id: uuid.UUID | None = Field(default=None)
+    forId: uuid.UUID | None = Field(default=None)
     mime: str | None = Field(default=None)
 
-    _upsert_index_elements = {"id"}
+
+class ChatElementResponse(ChatElement):
+    pass
 
 
 class ChatFeedback(MtmBaseSqlModel, table=True):
@@ -72,7 +74,7 @@ class ChatFeedback(MtmBaseSqlModel, table=True):
     value: int = Field(...)
     comment: str | None = Field(default=None)
 
-    _upsert_index_elements = {"id"}
+    # _upsert_index_elements = {"id"}
 
 
 class Starter(BaseModel):
@@ -89,7 +91,6 @@ class ChatProfile(MtmBaseSqlModel, table=True):
     description: str = Field(...)
     icon: str | None = Field(default=None)
     default: bool | None = Field(default=False)
-    # starters: list[dict] = Field(default=[])
     starters: list[dict] | None = Field(default=None, sa_column=Column(JSON))
 
 
@@ -107,6 +108,8 @@ class ThreadUIState(BaseModel):
     description: str | None = None
     icons: str | None = None
     layout: str | None = None
+    openWorkbench: bool | None = None
+    openChat: bool | None = None
     theme: str | None = None
     isOpen: bool | None = None
     screens: list[CopilotScreen] = Field(default_factory=list)
@@ -127,3 +130,99 @@ class ThreadUIState(BaseModel):
 
     playDataType: Literal["post", "demoArticle"] | None = None
     playData: dict | None = Field(default=None, sa_column=Column(JSON))
+
+
+class AssisantWorkBrench(BaseModel):
+    id: str
+    label: str
+    description: str
+    icon: str | None = None
+
+
+class AssisantStart(BaseModel):
+    title: str
+    message: str | None = None
+    icon: str | None = None
+
+
+class AssisantWelcome(BaseModel):
+    title: str
+    description: str | None = None
+
+
+class AssisantWorkbenchConfig(BaseModel):
+    workbenchs: list[AssisantWorkBrench]
+    workbench_default: str | None = None
+
+
+class AssisantContext(BaseModel):
+    siteId: str | None = None
+    userId: str | None = None
+    threadId: str | None = None
+    params: dict | None = None
+
+
+class AssisantMenus(BaseModel):
+    """
+    应用主菜单
+    """
+
+    id: str
+    label: str
+    icon: str | None = None
+    viewName: str | None = None
+    viewProps: dict | None = None
+    target: Literal["_blank", "_self", "workbench", "asider", "cmdk"] | None = None
+    children: list["AssisantMenus"] | None = None
+
+
+class SiderViewConfig(BaseModel):
+    """
+    侧边栏视图配置
+    """
+
+    id: str
+    label: str
+    icon: str | None = None
+    viewName: str | None = None
+    viewProps: dict | None = None
+
+
+class ListViewItemAdditionActions(BaseModel):
+    label: str
+    icon: str | None = None
+    action: str | None = None
+
+
+class ListViewProps(BaseModel):
+    isDev: bool | None = None
+    # 限制只能查询单个数据类型
+    dataType: str | None = None
+    # q: str | None = None
+    additionActions: list[ListViewItemAdditionActions] | None = None
+    searchParams: SearchRequest | None = None
+    variants: Literal["aside", "list", "grid"] | None = None
+    enableSearch: bool | None = None
+    enableFilter: bool | None = None
+    enableSort: bool | None = None
+    enablePagination: bool | None = None
+    enableExport: bool | None = None
+    enableImport: bool | None = None
+    enableCreate: bool | None = None
+    enableEdit: bool | None = None
+    enableDelete: bool | None = None
+    enableView: bool | None = None
+
+    createFormName: str | None = None
+    editFormName: str | None = None
+
+
+class AssisantConfig(BaseModel):
+    chatProfile: str
+    logo: str | None = None  # 站点logo 暂时没用上
+    welcome: AssisantWelcome | None = None
+    starts: list[AssisantStart]
+    workbench: AssisantWorkbenchConfig | None = None
+    context: AssisantContext | None = None
+    menus: list[AssisantMenus] | None = None
+    siderView: SiderViewConfig | None = None
