@@ -4,6 +4,7 @@ from enum import Enum
 
 from pgvector.sqlalchemy import Vector
 from pydantic import EmailStr
+from sqlalchemy import PrimaryKeyConstraint, UniqueConstraint
 from sqlmodel import JSON, Column, Field, Relationship, SQLModel
 
 
@@ -16,6 +17,7 @@ class UserBase(SQLModel):
     username: str | None = Field(default=None, max_length=255)
     identifier: str | None = Field(default=None, max_length=255)
     meta: dict | None = Field(default={}, sa_column=Column(JSON))
+    organization_id: str | None = Field(default=None, max_length=255)
 
 
 # Properties to receive via API on creation
@@ -45,7 +47,6 @@ class UpdatePassword(SQLModel):
     new_password: str = Field(min_length=6, max_length=40)
 
 
-# Database model, database table inferred from class name
 class User(UserBase, table=True):
     id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
     # id: str = Field(default_factory=mtutils.gen_orm_id_key, primary_key=True)
@@ -180,9 +181,6 @@ class StatusEnum(str, Enum):
 
 
 # 知识库相关
-
-
-# Shared properties
 class DocumentBase(SQLModel):
     class Config:
         arbitrary_types_allowed = True
@@ -215,55 +213,16 @@ class Document(DocumentBase, table=True):
     is_deleted: bool = Field(default=False, index=True)
 
 
-class DocumentIndex(SQLModel, table=True):
-    """文档索引表，用途 独立的向量数据库，通过相似查询定位Document
+class SysItem(SQLModel, table=True):
+    type: str = Field(index=True)
+    key: str = Field(index=True)
+    value: str
+    description: str | None = Field(default=None, max_length=255)
 
-    Args:
-        SQLModel (_type_): _description_
-        table (bool, optional): _description_. Defaults to True.
-    """
+    __table_args__ = (
+        PrimaryKeyConstraint("type", "key"),
+        UniqueConstraint("type", "key", name="sys_item_type_key_uc"),
+    )
 
-    id: uuid.UUID = Field(default_factory=uuid.uuid4, primary_key=True)
-    embedding: list[float] = Field(sa_column=Column(Vector()))
-    meta: dict | None = Field(default={}, sa_column=Column(JSON))
-    emb_model: str = Field(index=True)
-    created_at: datetime = Field(default_factory=datetime.now, nullable=False)
-    updated_at: datetime = Field(default_factory=datetime.now, nullable=False)
-    is_deleted: bool = Field(default=False, index=True)
-    # 类别
-    category: str = Field(default="", index=True)
-    # 过期时间
-    expired_at: datetime | None = Field(default=None)
-
-
-# class DocCollBase(SQLModel):
-#     title: str = Field(default="default", index=True)
-
-
-# class DocColl(DocCollBase, table=True):
-#     """
-#     知识库集
-#     """
-
-#     class Config:
-#         arbitrary_types_allowed = True
-
-#     id: str = Field(default_factory=mtutils.gen_orm_id_key, primary_key=True)
-#     # owner_id: str = Field(foreign_key="user.id", nullable=False, ondelete="CASCADE")
-#     # owner: User | None = Relationship(back_populates="doccolls")
-
-
-# # Properties to receive on item creation
-# class DocCollCreate(DocCollBase):
-#     pass
-
-
-# class DocCollPublic(SQLModel):
-#     id: str
-#     owner_id: str
-#     title: str
-
-
-# class DocCollsPublic(SQLModel):
-#     data: list[DocCollPublic]
-#     count: int
+    class Config:
+        table_name = "sys_item"
