@@ -3,14 +3,14 @@ import os
 import re
 from pathlib import Path
 
-from mtmlib.github import git_commit_push
-from mtmlib.mtutils import bash
-
 from mtmai.core import coreutils
 from mtmai.core.config import settings
 from mtmai.mtlibs import mtutils
-from mtmai.mtlibs.mtutils import command_exists, is_in_gitpod, npm_patch_version
+from mtmai.mtlibs.mtutils import (command_exists, is_in_gitpod,
+                                  npm_patch_version)
 from mtmai.mtlibs.temboio import run_tmpbo_instance1
+from mtmlib.github import git_commit_push
+from mtmlib.mtutils import bash
 
 # from mtmlib.version_tag import  read_tag
 
@@ -24,22 +24,17 @@ async def init_project():
         pass
     if not coreutils.is_in_gitpod():
         return
-    # init_github_settings()
-    # if not mtutils.command_exists("bun"):
-    #     bash("curl -fsSL https://bun.sh/install | bash")
-
     docker_config = Path.home().joinpath(".docker/config.json")
-    if settings.DOCKERHUB_PASSWORD and not docker_config.exists():
-        bash(
-            f"(command -v docker && echo {settings.DOCKERHUB_PASSWORD} | docker login --username {
-                settings.DOCKERHUB_USER} --password-stdin) || true"
-        )
-
-    if settings.NPM_TOKEN:
-        if is_in_gitpod():
-            Path.home().joinpath(".npmrc").write_text(
-                f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n"
-            )
+    # if settings.DOCKERHUB_PASSWORD and not docker_config.exists():
+    #     bash(
+    #         f"(command -v docker && echo {settings.DOCKERHUB_PASSWORD} | docker login --username {
+    #             settings.DOCKERHUB_USER} --password-stdin) || true"
+    #     )
+    # if settings.NPM_TOKEN:
+    #     if is_in_gitpod():
+    #         Path.home().joinpath(".npmrc").write_text(
+    #             f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n"
+    #         )
 
     # from mtmlib import tunnel
     # threading.Thread(target=lambda: asyncio.run(
@@ -164,7 +159,7 @@ def release_py():
 
     for project in py_projects:
         py_project_dir = f"pyprojects/{project}"
-        mtutils.pyproject_patch_version(py_project_dir)
+        mtutils.pyproject_patch_version(Path( py_project_dir).joinpath("pyproject.toml"))
 
     release_npm()
     # next_version = patch_git_tag_version()
