@@ -6,6 +6,7 @@ searxng_dir_base = "/app/searxng"
 searxng_setting_file = Path(searxng_dir_base) / "settings.yml"
 
 
+
 def install_searxng():
     script = f"""git clone https://github.com/searxng/searxng {searxng_dir_base} \
     && cd /app/searxng \
@@ -67,3 +68,9 @@ enabled_plugins:
     bash(
         f'cd {searxng_dir_base}  && export SEARXNG_SETTINGS_PATH="{searxng_setting_file}" && source .venv/bin/activate && python searx/webapp.py'
     )
+
+
+def run_searxng_server():
+    bash(
+        f'cd {searxng_dir_base}  && export SEARXNG_SETTINGS_PATH="{searxng_setting_file}" && . .venv/bin/activate && python searx/webapp.py &'
+    )
