@@ -1,14 +1,15 @@
 import asyncio
 import json
 import logging
+import re
 from pathlib import Path
 
 import httpx
 from fastapi import APIRouter
+from mtmlib.mtutils import bash
 
 from mtmai.core.config import settings
 from mtmai.mtlibs import mtutils
-from mtmlib.mtutils import bash
 
 router = APIRouter()
 
@@ -17,15 +18,18 @@ logger = logging.getLogger()
 
 # api 文档:  https://api.tembo.io/swagger-ui/#/instance/patch_instance
 
-def get_pyproject_version(project_dir: str = "."):
-    content = Path(f"{project_dir}/pyproject.toml").read_text()
+
+def get_pyproject_version(pyprojectTomlPath: str = "pyproject.toml"):
+    content = Path(pyprojectTomlPath).read_text()
     match = re.search(r'version\s*=\s*"(\d+\.\d+\.\d+)"', content)
     if not match:
         msg = "版本号未在 pyproject.toml 中找到"
         raise ValueError(msg)
     return match.group(1)
+
+
 async def docker_build_mtmai():
-    project_version = mtutils.get_pyproject_version("mtmai")
+    project_version = mtutils.get_pyproject_version("pyprojects/mtmai/pyproject.toml")
     logger.info("当前项目版本 %s", project_version)
 
     await asyncio.to_thread(
@@ -38,10 +42,13 @@ async def docker_build_mtmai():
 
 
 async def run_tmpbo_instance1():
-    project_version = mtutils.get_pyproject_version("mtmai")
+    python_project_dir = "pyprojects/mtmai"
+    project_version = mtutils.get_pyproject_version(
+        str(Path(python_project_dir).joinpath("pyproject.toml"))
+    )
     await asyncio.to_thread(
         bash,
-        "cd mtmai && poetry export --format requirements.txt --output requirements.txt --without-hashes --without dev",
+        f"cd {python_project_dir} && poetry export --format requirements.txt --output requirements.txt --without-hashes --without dev",
     )
     await docker_build_mtmai()
 
