@@ -31,7 +31,6 @@ from mtmai.forge.sdk.db.exceptions import NotFoundError
 from mtmai.forge.sdk.settings_manager import SettingsManager
 from mtmai.middleware import AuthMiddleware
 from mtmai.workflows.workers import deploy_mtmai_workers
-# from mtmai.workflows.wfapp import start_hatchet_worker
 
 LOG = structlog.stdlib.get_logger()
 
@@ -272,18 +271,18 @@ def build_app():
         )
         app.add_middleware(AuthMiddleware)
 
-    def mount_chainlit_router():
-        from mtmai.chainlit.utils import mount_chainlit
+    # def mount_chainlit_router():
+    #     from mtmai.chainlit.utils import mount_chainlit
 
-        chainit_app_path = os.path.join(os.path.dirname(__file__), "api/chat.py")
-        # logger.info("chainit_app_path: %s", chainit_app_path)
-        mount_chainlit(
-            app=app,
-            target=chainit_app_path,
-            path=settings.API_V1_STR + "/chat",
-        )
+    #     chainit_app_path = os.path.join(os.path.dirname(__file__), "api/chat.py")
+    #     # logger.info("chainit_app_path: %s", chainit_app_path)
+    #     mount_chainlit(
+    #         app=app,
+    #         target=chainit_app_path,
+    #         path=settings.API_V1_STR + "/chat",
+    #     )
 
-    mount_chainlit_router()
+    # mount_chainlit_router()
 
     setup_forge_app(app)
 
