@@ -11,8 +11,8 @@ from sqlmodel.ext.asyncio.session import AsyncSession as SQLModelAsyncSession
 from sqlmodel.pool import StaticPool
 
 from mtmai.core.config import settings
-from mtmai.core.db import init_db
-from mtmai.core.seed import seed_db
+from mtmai.db.db import init_db
+from mtmai.cli.seed import seed_db
 
 # from mtmai.server import build_app
 from mtmai.tests.utils.user import authentication_token_from_email
