@@ -1,6 +1,6 @@
 from sqlmodel import Session
 
-from mtmai.crud import crud
+from mtmai.crud import curd
 from mtmai.models.models import Item, ItemCreate
 from mtmai.tests.utils.user import create_random_user
 from mtmai.tests.utils.utils import random_lower_string
@@ -13,4 +13,4 @@ def create_random_item(db: Session) -> Item:
     title = random_lower_string()
     description = random_lower_string()
     item_in = ItemCreate(title=title, description=description)
-    return crud.create_item(session=db, item_in=item_in, owner_id=owner_id)
+    return curd.create_item(session=db, item_in=item_in, owner_id=owner_id)
